# HDI_Indicators12-30-15.R  N Maizlish  12/30/2015
# Reads source files for HDI and computes numerator, denominator,
# percentage or rate, standard error of the percent, RSE

# set working directory
setwd (" ")
# Get todays date to assign version
# today <- Sys.Date()
today <- date()

# turn off scientific notation
options(scipen=999)

#################### Total Population and Group Quarters ################
# Read 2010 Decennial DP01 source file
header <- read.csv(file= "DEC_10_DP_DPDP1.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
dp01 <- read.csv(file= "DEC_10_DP_DPDP1.csv", skip=2, header=FALSE, sep=",")
colnames(dp01) <- unlist(header)

# Keep variables of interest
dp01 <- dp01[, c("GEO.id2", "HD01_S001","HD02_S143")]

names(dp01)[names(dp01)=="GEO.id2"] <-"FIPS"
names(dp01)[names(dp01)=="HD01_S001"] <-"pop2010"
names(dp01)[names(dp01)=="HD02_S143"] <-"pct2010gq"

# Count the number of census tracts < 1500 population and >50% group quarters
dp01$popeq0 <- ifelse(dp01$pop2010 == 0, "zero_pop", "non_zero_pop")
dp01$poplt1500 <- ifelse(dp01$pop2010 < 1500, "lt.1500", "ge.1500")
dp01$grpqrtr50 <- ifelse(dp01$pct2010gq < 50, "lt.50pct", "ge.50pct")

# Determine number of exclusions
# Census tracts with 0 population
table(dp01$popeq0)

# Exclusions by population and group quarters
inc_ex_tbl <- table(dp01$poplt1500, dp01$grpqrtr50, dnn=c("Population","Group Quarters"))
addmargins(inc_ex_tbl)

# Subset qualifying census tracts
hdi_ct <- subset(dp01, dp01$pop2010 >= 1500 & dp01$ pct2010gq < 50)
nrow(hdi_ct)
hdi_ct$County_FIPS <- as.numeric(substr(as.character(hdi_ct$FIPS),1,4))

# Read county FIPS file
county_fips <-read.csv(file= "CA_County_FIPS2010.csv", head=TRUE, sep=",")

# Merge with county file
hdi_ct <- merge(hdi_ct, county_fips, by="County_FIPS")
nrow(hdi_ct)

# Keep variables of interest
hdi_ct <- hdi_ct[, c("FIPS","pop2010", "pct2010gq", "County_FIPS", "County_Name")]

# Write out datafile
write.csv(hdi_ct, "hdi_ref_ct.csv", row.names=FALSE)

########################### CalEnviroScreen Data #####################

####################### Asthma   ################
# April 2014 version
# ces2 <- read.csv(file= "CalEnviroScreen_v20.csv", head=TRUE, sep=",", na.strings=c("NA"))

# October 2014 Updated Version
ces2 <- read.csv(file= "CES20UpdateOct2014.csv", head=TRUE, sep=",", na.strings=c("NA"))

# Keep variables of interest
hdi <- ces2[, c("Census_Tract", "Asthma")]

# Rename variables of interest
names(hdi)[names(hdi)=="Census_Tract"] <-"FIPS"
names(hdi)[names(hdi)=="Asthma"] <-"percent"

# merge files 
hdi <- merge(hdi_ct, hdi,by="FIPS", all.x=TRUE)

# Calculate percent and standard error and relative standard error
hdi$numerator  <- NA
hdi$denominator <- NA
hdi$se_pct     <- NA
hdi$rse <- NA

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent)) 
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

# Look at summary statistics including missing values
summary(hdi$hdi_percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "asthma_d"
names(hdi)[names(hdi)=="numerator"]   <- "asthma_n"
names(hdi)[names(hdi)=="percent"]     <- "asthma_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "asthma_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "asthma_rse"
names(hdi)[names(hdi)=="pctile"]      <- "asthma_pctile"


#Label files with indicator, source, and version
hdi$indicator <- "Spatially modeled, age-adjusted rate of emergency department (ED) visits for asthma per 10,000"
hdi$reportyear <-"2007-2009"
hdi$source <- "CES2OCT2014"
hdi$version <- today

asthma <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "asthma_n", "asthma_d","asthma_pct", "asthma_se_pct", "asthma_rse", "asthma_pctile", "source", "version")]

# Write out datafile
write.csv(asthma, "hdi_asthma.csv", row.names=FALSE)

####################### Low Birth Weight   ################

# Keep variables of interest
hdi <- ces2[, c("Census_Tract", "Low_Birth_Weight")]

# Rename variables of interest
names(hdi)[names(hdi)=="Census_Tract"] <-"FIPS"
names(hdi)[names(hdi)=="Low_Birth_Weight"] <-"percent"

# merge files 
hdi <- merge(hdi_ct, hdi,by="FIPS", all.x=TRUE)

# Calculate percent and standard error and relative standard error
# convert proportion to percent
hdi$percent  <- 100*hdi$percent 
hdi$numerator  <- NA
hdi$denominator <- NA
hdi$se_pct     <- NA
hdi$rse <- NA

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent)) 
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)


# Look at summary statistics including missing values
# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "lbw_d"
names(hdi)[names(hdi)=="numerator"]   <- "lbw_n"
names(hdi)[names(hdi)=="percent"]     <- "lbw_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "lbw_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "lbw_rse"
names(hdi)[names(hdi)=="pctile"]      <- "lbw_pctile"


#Label files with indicator, source, and version
hdi$indicator <- "Percent low birth weight, spatially modeled"
hdi$reportyear <-"2006-2009"
hdi$source <- "CES2OCT2014"
hdi$version <- today

lbw <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "lbw_n", "lbw_d","lbw_pct", "lbw_se_pct", "lbw_rse", "lbw_pctile", "source", "version")]

# Write out datafile
write.csv(lbw, "hdi_lbw.csv", row.names=FALSE)


####################### PM 2.5   ################

# Keep variables of interest
hdi <- ces2[, c("Census_Tract", "PM25")]

# Rename variables of interest
names(hdi)[names(hdi)=="Census_Tract"] <-"FIPS"
names(hdi)[names(hdi)=="PM25"] <-"percent"

# merge files 
hdi <- merge(hdi_ct, hdi,by="FIPS", all.x=TRUE)

# Calculate percent and standard error and relative standard error
hdi$numerator  <- NA
hdi$denominator <- NA
hdi$se_pct     <- NA
hdi$rse <- NA

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent)) 
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "pm25_d"
names(hdi)[names(hdi)=="numerator"]   <- "pm25_n"
names(hdi)[names(hdi)=="percent"]     <- "pm25_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "pm25_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "pm25_rse"
names(hdi)[names(hdi)=="pctile"]      <- "pm25_pctile"


#Label files with indicator, source, and version
hdi$indicator <- "Three-year annual mean concentration of PM2.5"
hdi$reportyear <-"2009-2011"
hdi$source <- "CES2OCT2014"
hdi$version <- today

pm25 <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "pm25_n", "pm25_d","pm25_pct", "pm25_se_pct", "pm25_rse", "pm25_pctile", "source", "version")]

# Write out datafile
write.csv(pm25, "hdi_pm25.csv", row.names=FALSE)

####################### Traffic    ################

# Keep variables of interest
hdi <- ces2[, c("Census_Tract", "Traffic")]

# Rename variables of interest
names(hdi)[names(hdi)=="Census_Tract"] <-"FIPS"
names(hdi)[names(hdi)=="Traffic"] <-"percent"

# merge files 
hdi <- merge(hdi_ct, hdi,by="FIPS", all.x=TRUE)

# Calculate percent and standard error and relative standard error
hdi$numerator  <- NA
hdi$denominator <- NA
hdi$se_pct     <- NA
hdi$rse <- NA

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent)) 
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)


# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "traffic_d"
names(hdi)[names(hdi)=="numerator"]   <- "traffic_n"
names(hdi)[names(hdi)=="percent"]     <- "traffic_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "traffic_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "traffic_rse"
names(hdi)[names(hdi)=="pctile"]      <- "traffic_pctile"


#Label files with indicator, source, and version
hdi$indicator <- "Traffic density  Sum of traffic volumes adjusted by road segment length (vehicle-kph) divided by total road length (km) within 150 meters of the census tract boundary"
hdi$reportyear <-"2004"
hdi$source <- "CES2OCT2014"
hdi$version <- today

traffic <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "traffic_n", "traffic_d","traffic_pct", "traffic_se_pct", "traffic_rse", "traffic_pctile", "source", "version")]

# Write out datafile
write.csv(traffic, "hdi_traffic.csv", row.names=FALSE)


########### American Community Survey Data ##########################

# set working directory
setwd ("")

####################### Housing Cost Burden to Renters ################
# Read ACS5YR2012 DP04 source file

header <- read.csv(file= "ACS_12_5YR_DP04.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
dp04 <- read.csv(file= "ACS_12_5YR_DP04.csv", skip=2, header=FALSE, sep=",")
colnames(dp04) <- unlist(header)

# Keep variables of interest
hdi <- dp04[, c("GEO.id2", "HC01_VC191","HC01_VC196", "HC04_VC196", "HC01_VC197", "HC04_VC197")]

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"
names(hdi)[names(hdi)=="HC01_VC191"] <-"denominator"
names(hdi)[names(hdi)=="HC01_VC196"] <-"numerator1"
names(hdi)[names(hdi)=="HC01_VC197"] <-"numerator2"
names(hdi)[names(hdi)=="HC04_VC196"] <-"moe_pct1"
names(hdi)[names(hdi)=="HC04_VC197"] <-"moe_pct2"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
hdi$numerator = hdi$numerator1 + hdi$numerator2 
hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_pct    = ((hdi$moe_pct1/1.645)^2 + (hdi$moe_pct2/1.645)^2)^0.5
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 10000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent)) 
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "costburden_d"
names(hdi)[names(hdi)=="numerator"]   <- "costburden_n"
names(hdi)[names(hdi)=="percent"]     <- "costburden_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "costburden_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "costburden_rse"
names(hdi)[names(hdi)=="pctile"]      <- "costburden_pctile"


#Label files with indicator, source, and version
hdi$indicator <- "Percentage of renter households paying more than 30% of income on rent"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_DP04"
hdi$version <- today

costburden <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "costburden_n", "costburden_d","costburden_pct", "costburden_se_pct", "costburden_rse", "costburden_pctile", "source", "version")]

# Write out datafile
write.csv(costburden, "hdi_costburden.csv", row.names=FALSE)


####################### Housing Overcrowding #######################
# Read ACS5YR2012 DP04 source file

# header <- read.csv(file= "ACS_12_5YR_DP04.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
# dp04 <- read.csv(file= "ACS_12_5YR_DP04.csv", skip=2, header=FALSE, sep=",")
# colnames(dp04) <- unlist(header)

# Keep variables of interest
hdi <- dp04[, c("GEO.id2", "HC01_VC109","HC01_VC111", "HC04_VC111", "HC01_VC112", "HC04_VC112")]

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"
names(hdi)[names(hdi)=="HC01_VC109"] <-"denominator"
names(hdi)[names(hdi)=="HC01_VC111"] <-"numerator1"
names(hdi)[names(hdi)=="HC01_VC112"] <-"numerator2"
names(hdi)[names(hdi)=="HC04_VC111"] <-"moe_pct1"
names(hdi)[names(hdi)=="HC04_VC112"] <-"moe_pct2"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
hdi$numerator = hdi$numerator1 + hdi$numerator2 
hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_pct    = ((hdi$moe_pct1/1.645)^2 + (hdi$moe_pct2/1.645)^2)^0.5
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 10000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "crowded_d"
names(hdi)[names(hdi)=="numerator"]   <- "crowded_n"
names(hdi)[names(hdi)=="percent"]     <- "crowded_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "crowded_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "crowded_rse"
names(hdi)[names(hdi)=="pctile"]      <- "crowded_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of households with more than 1 occupant per room"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_DP04"
hdi$version <- today

# Save variable of interest and order variables
crowded <- hdi[,c("indicator", "reportyear", "FIPS", "crowded_n", "crowded_d","crowded_pct", "crowded_se_pct", "crowded_rse", "crowded_pctile", "source", "version")]

# Write out datafile
write.csv(crowded, "hdi_crowded.csv", row.names=FALSE)

####################### Disability #######################
# Read ACS5YR2012 DP02 source file

header <- read.csv(file= "ACS_12_5YR_DP02.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
dp02 <- read.csv(file= "ACS_12_5YR_DP02.csv", skip=2, header=FALSE, sep=",")
colnames(dp02) <- unlist(header)

# Keep variables of interest
hdi <- dp02[, c("GEO.id2", "HC01_VC103","HC01_VC104", "HC04_VC104")]

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"
names(hdi)[names(hdi)=="HC01_VC103"] <-"denominator"
names(hdi)[names(hdi)=="HC01_VC104"] <-"numerator"
names(hdi)[names(hdi)=="HC04_VC104"] <-"moe_pct"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_pct    = hdi$moe_pct/1.645
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)
  

summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "disability_d"
names(hdi)[names(hdi)=="numerator"]   <- "disability_n"
names(hdi)[names(hdi)=="percent"]     <- "disability_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "disability_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "disability_rse"
names(hdi)[names(hdi)=="pctile"]      <- "disability_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of the non-institutionalized population with any disability"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_DP02"
hdi$version <- today


disability <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "disability_n", "disability_d","disability_pct", "disability_se_pct", "disability_rse", "disability_pctile","source", "version")]

# Write out datafile
write.csv(disability,"hdi_disability.csv", row.names=FALSE)

####################### Median Household Income #######################
# Read ACS5YR2012 DP03 source file

header <- read.csv(file= "ACS_12_5YR_DP03.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
dp03 <- read.csv(file= "ACS_12_5YR_DP03.csv", skip=2, header=FALSE, sep=",")
colnames(dp03) <- unlist(header)

# Keep variables of interest
hdi <- dp03[, c("GEO.id2", "HC01_VC74", "HC01_VC85","HC02_VC85")]

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"
names(hdi)[names(hdi)=="HC01_VC74"] <-"denominator" # No. of households
names(hdi)[names(hdi)=="HC01_VC85"] <-"numerator"
names(hdi)[names(hdi)=="HC02_VC85"] <-"moe_pct"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
hdi$percent   = hdi$numerator 
hdi$se_pct    = hdi$moe_pct/1.645
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
# hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
# hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
# hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file
names(hdi)[names(hdi)=="denominator"] <- "income_d"
names(hdi)[names(hdi)=="numerator"]   <- "income_n"
names(hdi)[names(hdi)=="percent"]     <- "income_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "income_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "income_rse"
names(hdi)[names(hdi)=="pctile"]      <- "income_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Median annual household income"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_DP03"
hdi$version <- today

# Save variable of interest and order variables
income <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "income_n", "income_d","income_pct", "income_se_pct", "income_rse","income_pctile","source", "version")]

# Write out datafile
write.csv(income,"hdi_income.csv", row.names=FALSE)

####################### Noauto #######################
# Read ACS5YR2012 DP04 source file

# header <- read.csv(file= "ACS_12_5YR_DP02.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
# dp02 <- read.csv(file= "ACS_12_5YR_DP02.csv", skip=2, header=FALSE, sep=",")
# colnames(dp02) <- unlist(header)

# Keep variables of interest
hdi <- dp04[, c("GEO.id2", "HC01_VC81","HC01_VC82", "HC04_VC82")]

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"
names(hdi)[names(hdi)=="HC01_VC81"] <-"denominator"
names(hdi)[names(hdi)=="HC01_VC82"] <-"numerator"
names(hdi)[names(hdi)=="HC04_VC82"] <-"moe_pct"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_pct    = hdi$moe_pct/1.645
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

summary(hdi$rse)
# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "noauto_d"
names(hdi)[names(hdi)=="numerator"]   <- "noauto_n"
names(hdi)[names(hdi)=="percent"]     <- "noauto_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "noauto_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "noauto_rse"
names(hdi)[names(hdi)=="pctile"]      <- "noauto_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of households without access to an automobile"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_DP04"
hdi$version <- today

# Save variable of interest and order variables
noauto <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "noauto_n", "noauto_d","noauto_pct", "noauto_se_pct", "noauto_rse", "noauto_pctile", "source", "version")]

# Write out datafile
write.csv(noauto,"hdi_noauto.csv", row.names=FALSE)


####################### No English/Linguistic Isolation ################
# Read ACS5YR2012 DP04 source file

header <- read.csv(file= "ACS_12_5YR_B16002.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
b16002 <- read.csv(file= "ACS_12_5YR_B16002.csv", skip=2, header=FALSE, sep=",")
colnames(b16002) <- unlist(header)

# Keep variables of interest
hdi <- b16002[, c("GEO.id2", "HD01_VD01","HD01_VD04","HD01_VD07", "HD01_VD10", "HD01_VD13", "HD02_VD01","HD02_VD04","HD02_VD07", "HD02_VD10", "HD02_VD13")]

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"
names(hdi)[names(hdi)=="HD01_VD01"] <-"denominator"
names(hdi)[names(hdi)=="HD01_VD04"] <-"numerator1"
names(hdi)[names(hdi)=="HD01_VD07"] <-"numerator2"
names(hdi)[names(hdi)=="HD01_VD10"] <-"numerator3"
names(hdi)[names(hdi)=="HD01_VD13"] <-"numerator4"
names(hdi)[names(hdi)=="HD02_VD01"] <-"denominator_moe"
names(hdi)[names(hdi)=="HD02_VD04"] <-"numerator1_moe"
names(hdi)[names(hdi)=="HD02_VD07"] <-"numerator2_moe"
names(hdi)[names(hdi)=="HD02_VD10"] <-"numerator3_moe"
names(hdi)[names(hdi)=="HD02_VD13"] <-"numerator4_moe"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
hdi$numerator = hdi$numerator1 + hdi$numerator2 + hdi$numerator3 + hdi$numerator4
hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_y    = hdi$denominator_moe/1.645
hdi$se_x    = sqrt((hdi$numerator1_moe/1.645)^2 + (hdi$numerator2_moe/1.645)^2 + (hdi$numerator3_moe/1.645)^2 + (hdi$numerator4_moe/1.645)^2)
hdi$se_pct = 100*(1/hdi$denominator*sqrt(hdi$se_x^2 - (hdi$numerator^2/hdi$denominator^2)*hdi$se_y^2))
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "noenglish_d"
names(hdi)[names(hdi)=="numerator"]   <- "noenglish_n"
names(hdi)[names(hdi)=="percent"]     <- "noenglish_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "noenglish_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "noenglish_rse"
names(hdi)[names(hdi)=="pctile"]      <- "noenglish_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of household where no person at least 14 years old speaks English well"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_B16002"
hdi$version <- today

# Save variable of interest and order variables
noenglish <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "noenglish_n", "noenglish_d","noenglish_pct", "noenglish_se_pct", "noenglish_rse", "noenglish_pctile", "source", "version")]

# Write out datafile
write.csv(noenglish,"hdi_noenglish.csv", row.names=FALSE)

####################### Nohighschl #######################
# Read ACS5YR2012 DP02 source file

# header <- read.csv(file= "ACS_12_5YR_DP02.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
# dp02 <- read.csv(file= "ACS_12_5YR_DP02.csv", skip=2, header=FALSE, sep=",")
# colnames(dp02) <- unlist(header)

# Keep variables of interest
hdi <- dp02[, c("GEO.id2", "HC01_VC84", "HC01_VC85", "HC01_VC86", "HC04_VC93")]

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"
names(hdi)[names(hdi)=="HC01_VC84"] <-"denominator"
names(hdi)[names(hdi)=="HC01_VC85"] <-"numerator1"
names(hdi)[names(hdi)=="HC01_VC86"] <-"numerator2"
names(hdi)[names(hdi)=="HC04_VC93"] <-"moe_pct"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
hdi$numerator = hdi$numerator1 + hdi$numerator2
hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_pct    = hdi$moe_pct/1.645
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)


summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "nohighschl_d"
names(hdi)[names(hdi)=="numerator"]   <- "nohighschl_n"
names(hdi)[names(hdi)=="percent"]     <- "nohighschl_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "nohighschl_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "nohighschl_rse"
names(hdi)[names(hdi)=="pctile"]      <- "nohighschl_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of population over age 25 without a high school education"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_DP02"
hdi$version <- today

# Save variable of interest and order variables
nohighschl <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "nohighschl_n", "nohighschl_d","nohighschl_pct", "nohighschl_se_pct", "nohighschl_rse", "nohighschl_pctile", "source", "version")]

# Write out datafile
write.csv(nohighschl,"hdi_nohighschl.csv", row.names=FALSE)


####################### Nokitchen #######################
# Read ACS5YR2012 DP04 source file

# header <- read.csv(file= "ACS_12_5YR_DP02.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
# dp02 <- read.csv(file= "ACS_12_5YR_DP02.csv", skip=2, header=FALSE, sep=",")
# colnames(dp02) <- unlist(header)

# Keep variables of interest
hdi <- dp04[, c("GEO.id2", "HC01_VC102","HC01_VC104", "HC04_VC104")]

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"
names(hdi)[names(hdi)=="HC01_VC102"] <-"denominator"
names(hdi)[names(hdi)=="HC01_VC104"] <-"numerator"
names(hdi)[names(hdi)=="HC04_VC104"] <-"moe_pct"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_pct    = hdi$moe_pct/1.645
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "nokitchen_d"
names(hdi)[names(hdi)=="numerator"]   <- "nokitchen_n"
names(hdi)[names(hdi)=="percent"]     <- "nokitchen_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "nokitchen_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "nokitchen_rse"
names(hdi)[names(hdi)=="pctile"]      <- "nokitchen_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of the population in homes lacking complete kitchen facilities"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_DP04"
hdi$version <- today

# Save variable of interest and order variables
nokitchen <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "nokitchen_n", "nokitchen_d","nokitchen_pct", "nokitchen_se_pct", "nokitchen_rse", "nokitchen_pctile", "source", "version")]

# Write out datafile
write.csv(nokitchen,"hdi_nokitchen.csv", row.names=FALSE)


####################### Not Enrolled in High School ################
# Read ACS5YR2012 B14003 source file

header <- read.csv(file= "ACS_12_5YR_B14003.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
b14003 <- read.csv(file= "ACS_12_5YR_B14003.csv", skip=2, header=FALSE, sep=",")
colnames(b14003) <- unlist(header)

# Keep variables of interest
hdi <- b14003[, c("GEO.id2", "HD01_VD07","HD01_VD16","HD01_VD25", "HD01_VD35", "HD01_VD44", "HD01_VD53", "HD02_VD07", "HD02_VD16", "HD02_VD25", "HD02_VD35", "HD02_VD44", "HD02_VD53")]

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"
# Male, N 
names(hdi)[names(hdi)=="HD01_VD07"] <-"denominator1"
names(hdi)[names(hdi)=="HD01_VD16"] <-"denominator2"
names(hdi)[names(hdi)=="HD01_VD25"] <-"denominator3"
#Female, N
names(hdi)[names(hdi)=="HD01_VD35"] <-"denominator4"
names(hdi)[names(hdi)=="HD01_VD44"] <-"denominator5"
names(hdi)[names(hdi)=="HD01_VD53"] <-"denominator6"
#Male, N
names(hdi)[names(hdi)=="HD02_VD07"] <-"denominator1_moe"
names(hdi)[names(hdi)=="HD02_VD16"] <-"denominator2_moe"
names(hdi)[names(hdi)=="HD02_VD25"] <-"denominator3_moe"
#Female, N
names(hdi)[names(hdi)=="HD02_VD35"] <-"denominator4_moe"
names(hdi)[names(hdi)=="HD02_VD44"] <-"denominator5_moe"
names(hdi)[names(hdi)=="HD02_VD53"] <-"denominator6_moe"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
# Denominator
hdi$denominator = hdi$denominator1 + hdi$denominator2 + hdi$denominator3 + hdi$denominator4 + hdi$denominator5 + hdi$denominator6 
hdi$numerator = hdi$denominator3 + hdi$denominator6 
hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_y    = sqrt((hdi$denominator1_moe/1.645)^2 + (hdi$denominator2_moe/1.645)^2 + (hdi$denominator3_moe/1.645)^2 + (hdi$denominator4_moe/1.645)^2 + (hdi$denominator5_moe/1.645)^2 + (hdi$denominator6_moe/1.645)^2)
hdi$se_x    = sqrt((hdi$denominator3_moe/1.645)^2 +  (hdi$denominator6_moe/1.645)^2)
hdi$se_pct = 100*(1/hdi$denominator*sqrt(hdi$se_x^2 - (hdi$numerator^2/hdi$denominator^2)*hdi$se_y^2))
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent, na.last = TRUE)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)


summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "notinhiscl_d"
names(hdi)[names(hdi)=="numerator"]   <- "notinhiscl_n"
names(hdi)[names(hdi)=="percent"]     <- "notinhiscl_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "notinhiscl_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "notinhiscl_rse"
names(hdi)[names(hdi)=="pctile"]      <- "notinhiscl_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of 15-17 year olds not enrolled in school"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_B14003"
hdi$version <- today

# Save variable of interest and order variables
notinhiscl <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "notinhiscl_n", "notinhiscl_d","notinhiscl_pct", "notinhiscl_se_pct", "notinhiscl_rse", "notinhiscl_pctile", "source", "version")]

# Write out datafile
write.csv(notinhiscl,"hdi_notinhiscl.csv", row.names=FALSE)


####################### Not Enrolled in Primary School ################
# Read ACS5YR2012 B14003 source file

header <- read.csv(file= "ACS_12_5YR_B14003.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
b14003 <- read.csv(file= "ACS_12_5YR_B14003.csv", skip=2, header=FALSE, sep=",")
colnames(b14003) <- unlist(header)

# Keep variables of interest
hdi <- b14003[, c("GEO.id2", "HD01_VD04","HD01_VD13","HD01_VD22", "HD01_VD32", "HD01_VD41", "HD01_VD50", "HD02_VD04", "HD02_VD13", "HD02_VD22", "HD02_VD32", "HD02_VD41", "HD02_VD50")]

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"
# Male, N 
names(hdi)[names(hdi)=="HD01_VD04"] <-"denominator1"
names(hdi)[names(hdi)=="HD01_VD13"] <-"denominator2"
names(hdi)[names(hdi)=="HD01_VD22"] <-"denominator3"
#Female, N
names(hdi)[names(hdi)=="HD01_VD32"] <-"denominator4"
names(hdi)[names(hdi)=="HD01_VD41"] <-"denominator5"
names(hdi)[names(hdi)=="HD01_VD50"] <-"denominator6"
#Male, N
names(hdi)[names(hdi)=="HD02_VD04"] <-"denominator1_moe"
names(hdi)[names(hdi)=="HD02_VD13"] <-"denominator2_moe"
names(hdi)[names(hdi)=="HD02_VD22"] <-"denominator3_moe"
#Female, N
names(hdi)[names(hdi)=="HD02_VD32"] <-"denominator4_moe"
names(hdi)[names(hdi)=="HD02_VD41"] <-"denominator5_moe"
names(hdi)[names(hdi)=="HD02_VD50"] <-"denominator6_moe"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
# Denominator
hdi$denominator = hdi$denominator1 + hdi$denominator2 + hdi$denominator3 + hdi$denominator4 + hdi$denominator5 + hdi$denominator6 
hdi$numerator = hdi$denominator3 + hdi$denominator6 
hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_y    = sqrt((hdi$denominator1_moe/1.645)^2 + (hdi$denominator2_moe/1.645)^2 + (hdi$denominator3_moe/1.645)^2 + (hdi$denominator4_moe/1.645)^2 + (hdi$denominator5_moe/1.645)^2 + (hdi$denominator6_moe/1.645)^2)
hdi$se_x    = sqrt((hdi$denominator3_moe/1.645)^2 +  (hdi$denominator6_moe/1.645)^2)
hdi$se_pct = 100*(1/hdi$denominator*sqrt(hdi$se_x^2 - (hdi$numerator^2/hdi$denominator^2)*hdi$se_y^2))
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent, na.last = TRUE)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)


summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)
# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "notinprscl_d"
names(hdi)[names(hdi)=="numerator"]   <- "notinprscl_n"
names(hdi)[names(hdi)=="percent"]     <- "notinprscl_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "notinprscl_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "notinprscl_rse"
names(hdi)[names(hdi)=="pctile"]      <- "notinprscl_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of 3 and 4 year olds not enrolled in school"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_B14003"
hdi$version <- today

# Save variable of interest and order variables
notinprscl <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "notinprscl_n", "notinprscl_d","notinprscl_pct", "notinprscl_se_pct", "notinprscl_rse", "notinprscl_pctile", "source", "version")]

# Write out datafile
write.csv(notinprscl,"hdi_notinprscl.csv", row.names=FALSE)


####################### Nowork #######################
# Read ACS5YR2012 S2301 source file

header <- read.csv(file= "ACS_12_5YR_S2301.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
s2301 <- read.csv(file= "ACS_12_5YR_S2301.csv", skip=2, header=FALSE, sep=",")
colnames(s2301) <- unlist(header)

# Keep variables of interest
hdi <- s2301[, c("GEO.id2", "HC01_EST_VC38", "HC02_EST_VC38", "HC04_EST_VC38", "HC04_MOE_VC38")]

# Educational attainment file
# HC01_EST_VC38 Total; Estimate; Population 25 to 64 years
# HC02_EST_VC38 In labor force; Estimate; Population 25 to 64 years, %
# HC04_EST_VC38 Unemployment rate; Estimate; Population 25 to 64 years
# HC04_MOE_VC38 Unemployment rate; MOE; Population 25 to 64 years
# Denominator = HC01_EST_VC38 * HC02_EST_VC38/100
# Numerator   = (HC04_EST_VC38/100)*Denominator
# Percent = Numerator/denominator or HC04_EST_VC38/100
# se_pct =(HC04_MOE_VC38/1.645)/100	

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
hdi$denominator = hdi$HC01_EST_VC38 * hdi$HC02_EST_VC38/100
hdi$numerator = (hdi$HC04_EST_VC38/100)*hdi$denominator

hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_pct    = hdi$HC04_MOE_VC38/1.645
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "nowork_d"
names(hdi)[names(hdi)=="numerator"]   <- "nowork_n"
names(hdi)[names(hdi)=="percent"]     <- "nowork_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "nowork_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "nowork_rse"
names(hdi)[names(hdi)=="pctile"]      <- "nowork_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of population aged 25-64 who are unemployed"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_S2301"
hdi$version <- today

# Save variable of interest and order variables
nowork <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "nowork_n", "nowork_d","nowork_pct", "nowork_se_pct", "nowork_rse", "nowork_pctile", "source", "version")]

# Write out datafile
write.csv(nowork,"hdi_nowork.csv", row.names=FALSE)


####################### Poverty (<200%FPL ages 0-64 years ##############
# Read ACS5YR2012 b17024 source file

header <- read.csv(file= "ACS_12_5YR_B17024.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
b17024 <- read.csv(file= "ACS_12_5YR_B17024.csv", skip=2, header=FALSE, sep=",")
colnames(b17024) <- unlist(header)

# Keep variables of interest
hdi <- b17024[, c("GEO.id2", "HD01_VD02", "HD01_VD03", "HD01_VD04", "HD01_VD05", "HD01_VD06", "HD01_VD07", "HD01_VD08", "HD01_VD09", "HD01_VD10", "HD01_VD54", "HD01_VD55", "HD01_VD56", "HD01_VD57", "HD01_VD58", "HD01_VD59", "HD01_VD60", "HD01_VD61", "HD01_VD62", "HD01_VD15", "HD01_VD16", "HD01_VD17", "HD01_VD18", "HD01_VD19", "HD01_VD20", "HD01_VD21", "HD01_VD22", "HD01_VD23", "HD01_VD67", "HD01_VD68", "HD01_VD69", "HD01_VD70", "HD01_VD71", "HD01_VD72", "HD01_VD73", "HD01_VD74", "HD01_VD75", "HD01_VD28", "HD01_VD29", "HD01_VD30", "HD01_VD31", "HD01_VD32", "HD01_VD33", "HD01_VD34", "HD01_VD35", "HD01_VD36", "HD01_VD80", "HD01_VD81", "HD01_VD82", "HD01_VD83", "HD01_VD84", "HD01_VD85", "HD01_VD86", "HD01_VD87", "HD01_VD88", "HD01_VD41", "HD01_VD42", "HD01_VD43", "HD01_VD44", "HD01_VD45", "HD01_VD46", "HD01_VD47", "HD01_VD48", "HD01_VD49", "HD01_VD93", "HD01_VD94", "HD01_VD95", "HD01_VD96", "HD01_VD97", "HD01_VD98", "HD01_VD99", "HD01_VD100", "HD01_VD101")] 

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
# Aggregate 8 poverty ranges:  Under .50, .50 to .74, .75 to .99, 1.00 to
# 1.24, 1.25 to 1.49, 1.50 to 1.74, 1.75 to 1.84, 1.85 to 1.99 

# Age categories: Under 6 years + 6 to 11 years + 12 to 17  years + 18 to 24
# years + 25 to 34 years + 35 to 44 years + 45 to 54 years + 55 to 64 years 

hdi$denominator <- hdi$HD01_VD02 + hdi$HD01_VD15 + hdi$HD01_VD28 + hdi$HD01_VD41 + hdi$HD01_VD54 + hdi$HD01_VD67 + hdi$HD01_VD80 + hdi$HD01_VD93

# Under 6 years
hdi$numerator1 = hdi$HD01_VD03 + hdi$HD01_VD04 + hdi$HD01_VD05 + hdi$HD01_VD06 + hdi$HD01_VD07 + hdi$HD01_VD08 + hdi$HD01_VD09 + hdi$HD01_VD10 

# 6 to 11 years
hdi$numerator2 = hdi$HD01_VD16 + hdi$HD01_VD17 + hdi$HD01_VD18 + hdi$HD01_VD19 + hdi$HD01_VD20 + hdi$HD01_VD21 + hdi$HD01_VD22 + hdi$HD01_VD23

# 12 to 17 years
hdi$numerator3 = hdi$HD01_VD29 + hdi$HD01_VD30 + hdi$HD01_VD31 + hdi$HD01_VD32 + hdi$HD01_VD33 + hdi$HD01_VD34 + hdi$HD01_VD35 + hdi$HD01_VD36

# 18 to 24 years
hdi$numerator4 = hdi$HD01_VD42 + hdi$HD01_VD43 + hdi$HD01_VD44 + hdi$HD01_VD45 + hdi$HD01_VD46 + hdi$HD01_VD47 + hdi$HD01_VD48 + hdi$HD01_VD49

# 25 to 34 years
hdi$numerator5 = hdi$HD01_VD55 + hdi$HD01_VD56 + hdi$HD01_VD57 + hdi$HD01_VD58 + hdi$HD01_VD59 + hdi$HD01_VD60 + hdi$HD01_VD61 + hdi$HD01_VD62

# 35 to 44 years
hdi$numerator6 = hdi$HD01_VD68 + hdi$HD01_VD69 + hdi$HD01_VD70 + hdi$HD01_VD71 + hdi$HD01_VD72 + hdi$HD01_VD73 + hdi$HD01_VD74 + hdi$HD01_VD75

# 45 to 54 years
hdi$numerator7 = hdi$HD01_VD81 + hdi$HD01_VD82 + hdi$HD01_VD83 + hdi$HD01_VD84 + hdi$HD01_VD85 + hdi$HD01_VD86 + hdi$HD01_VD87 + hdi$HD01_VD88

# 55 to 64 years
hdi$numerator8 = hdi$HD01_VD94 + hdi$HD01_VD95 + hdi$HD01_VD96 + hdi$HD01_VD97 + hdi$HD01_VD98 + hdi$HD01_VD99 + hdi$HD01_VD100 + hdi$HD01_VD101

hdi$numerator = hdi$numerator1 + hdi$numerator2 + hdi$numerator3 + hdi$numerator4 + hdi$numerator5 + hdi$numerator6 + hdi$numerator7 + hdi$numerator8 

hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_pct    <- NA	
hdi$rse <- NA

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <-replace(hdi$pctile, hdi$pctile > 100 , NA)


summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "poverty_d"
names(hdi)[names(hdi)=="numerator"]   <- "poverty_n"
names(hdi)[names(hdi)=="percent"]     <- "poverty_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "poverty_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "poverty_rse"
names(hdi)[names(hdi)=="pctile"]      <- "poverty_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of the population <= aged 64 with household incomes below twice the Federal Poverty Line"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_B17024"
hdi$version <- today

# Save variable of interest and order variables
poverty <- hdi[ ,c("indicator", "reportyear", "FIPS", "County_Name",  "County_FIPS", "poverty_n", "poverty_d", "poverty_pct", "poverty_se_pct", "poverty_rse", "poverty_pctile", "source", "version")]

# Write out datafile
write.csv(poverty, "hdi_poverty.csv", row.names=FALSE)


####################### Renters #######################
# Read ACS5YR2012 DP04 source file

# Keep variables of interest
hdi <- dp04[, c("GEO.id2", "HC01_VC62","HC01_VC64", "HC04_VC64")]

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"
names(hdi)[names(hdi)=="HC01_VC62"] <-"denominator"
names(hdi)[names(hdi)=="HC01_VC64"] <-"numerator"
names(hdi)[names(hdi)=="HC04_VC64"] <-"moe_pct"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_pct    = hdi$moe_pct/1.645
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "renters_d"
names(hdi)[names(hdi)=="numerator"]   <- "renters_n"
names(hdi)[names(hdi)=="percent"]     <- "renters_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "renters_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "renters_rse"
names(hdi)[names(hdi)=="pctile"]      <- "renters_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of occupied housing units not occupied by property owners"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_DP04"
hdi$version <- today

# Save variable of interest and order variables
renters <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "renters_n", "renters_d","renters_pct", "renters_se_pct", "renters_rse", "renters_pctile", "source", "version")]

# Write out datafile
write.csv(renters,"hdi_renters.csv", row.names=FALSE)


####################### Singlparnt #######################
# Read ACS5YR2012 DP02 source file

# header <- read.csv(file= "ACS_12_5YR_DP02.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
# dp02 <- read.csv(file= "ACS_12_5YR_DP02.csv", skip=2, header=FALSE, sep=",")
# colnames(dp02) <- unlist(header)

# Keep variables of interest
hdi <- dp02[, c("GEO.id2", "HC01_VC06", "HC01_VC10", "HC01_VC12", "HC04_VC10", "HC04_VC12")]

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"
names(hdi)[names(hdi)=="HC01_VC06"] <-"denominator"
names(hdi)[names(hdi)=="HC01_VC10"] <-"numerator1"
names(hdi)[names(hdi)=="HC01_VC12"] <-"numerator2"
names(hdi)[names(hdi)=="HC04_VC10"] <-"moe1_pct"
names(hdi)[names(hdi)=="HC04_VC12"] <-"moe2_pct"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
hdi$numerator = hdi$numerator1 + hdi$numerator2
hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_pct    = sqrt((hdi$moe1_pct/1.645)^2 + (hdi$moe2_pct/1.645)^2) 
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "singlparnt_d"
names(hdi)[names(hdi)=="numerator"]   <- "singlparnt_n"
names(hdi)[names(hdi)=="percent"]     <- "singlparnt_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "singlparnt_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "singlparnt_rse"
names(hdi)[names(hdi)=="pctile"]      <- "singlparnt_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of family households with children under 18 with only one parent"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_DP02"
hdi$version <- today

# Save variable of interest and order variables
singlparnt <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "singlparnt_n", "singlparnt_d","singlparnt_pct", "singlparnt_se_pct", "singlparnt_rse", "singlparnt_pctile", "source", "version")]

# Write out datafile
write.csv(singlparnt,"hdi_singlparnt.csv", row.names=FALSE)


####################### Uninsured #######################
# Read ACS5YR2012 DP03 source file

# Keep variables of interest
hdi <- dp03[, c("GEO.id2", "HC01_VC127","HC01_VC131", "HC04_VC131")]

# Rename variables of interest
names(hdi)[names(hdi)=="GEO.id2"] <-"FIPS"
names(hdi)[names(hdi)=="HC01_VC127"] <-"denominator"
names(hdi)[names(hdi)=="HC01_VC131"] <-"numerator"
names(hdi)[names(hdi)=="HC04_VC131"] <-"moe_pct"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_pct    = hdi$moe_pct/1.645
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "uninsured_d"
names(hdi)[names(hdi)=="numerator"]   <- "uninsured_n"
names(hdi)[names(hdi)=="percent"]     <- "uninsured_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "uninsured_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "uninsured_rse"
names(hdi)[names(hdi)=="pctile"]      <- "uninsured_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of the population without health insurance"
hdi$reportyear <-"2008-2012"
hdi$source <- "ACS_12_5YR_DP03"
hdi$version <- today

# Save variable of interest and order variables
uninsured <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "uninsured_n", "uninsured_d","uninsured_pct", "uninsured_se_pct", "uninsured_rse", "uninsured_pctile", "source", "version")]

# Write out datafile
write.csv(uninsured,"hdi_uninsured.csv", row.names=FALSE)

####################### Novoter10 #######################

################## Read Statewide 2010 Registration File ###############
vr2010blk <- read.csv(file= "statewide_reg_stats_by_block2010.csv", header=TRUE, sep=",", na.strings=c("NA"))

# Keep variables of interest
vr2010blk <- vr2010blk[, c("geoid10", "totreg_r")]
nrow(vr2010blk)

# Create census tract ID
vr2010blk$FIPS <- as.numeric(substr(as.character(vr2010blk$geoid10),1,10))

# Aggregate and create a new file
vr2010ct <-aggregate(vr2010blk,by=list(vr2010blk$FIPS), FUN=sum, na.rm=TRUE)

# Keep variables of interest
names(vr2010ct)[names(vr2010ct)=="Group.1"] <-"FIPS"
vr2010ct <- vr2010ct[, c("FIPS", "totreg_r")]
nrow(vr2010ct)


################ Non Voters #######################

nv2010blk <- read.csv(file= "statewide2010_novote_stats_by_block.csv", header=TRUE, sep=",", na.strings=c("NA"))

# Keep variables of interest
nv2010blk <- nv2010blk[, c("geoid10", "totreg_r")]
nrow(nv2010blk)

# Create census tract ID
nv2010blk$FIPS <- as.numeric(substr(as.character(nv2010blk$geoid10),1,10))

# Aggregate and create a new file
nv2010ct <-aggregate(nv2010blk,by=list(nv2010blk$FIPS), FUN=sum, na.rm=TRUE)

# Keep variables of interest
names(nv2010ct)[names(nv2010ct)=="Group.1"] <-"FIPS"
names(nv2010ct)[names(nv2010ct)=="totreg_r"] <-"totreg_n"

nv2010ct <- nv2010ct[, c("FIPS", "totreg_n")]
nrow(vr2010ct)

# merge files together
hdi <- merge(vr2010ct, nv2010ct, by="FIPS", all=TRUE)

# Rename variables of interest
names(hdi)[names(hdi)=="totreg_r"] <-"denominator"
names(hdi)[names(hdi)=="totreg_n"] <-"numerator"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
hdi$percent   = 100*hdi$numerator/hdi$denominator
hdi$se_pct   = sqrt(hdi$percent*(100-hdi$percent)/hdi$denominator)

hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "novoter10_d"
names(hdi)[names(hdi)=="numerator"]   <- "novoter10_n"
names(hdi)[names(hdi)=="percent"]     <- "novoter10_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "novoter10_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "novoter10_rse"
names(hdi)[names(hdi)=="pctile"]      <- "novoter10_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of registered voters not voting in the 2010 general election"
hdi$reportyear <-"2010"
hdi$source <- "UC Berkeley Statewide Database"
hdi$version <- today

# Save variable of interest and order variables
novoter10 <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "novoter10_n", "novoter10_d","novoter10_pct", "novoter10_se_pct", "novoter10_rse", "novoter10_pctile", "source", "version")]

# Write out datafile
write.csv(novoter10,"hdi_novoter10.csv", row.names=FALSE)


############## Read Statewide 2012 Precinct to Block Map ###############

# Map file has total number of registered voters by block and percent
# of precinct in block
p2bmap <- read.csv(file= "state_g12_rg_blk_map.csv", header=TRUE, sep=",", na.strings=c("NA"))
nrow(p2bmap)


################ Voters by Precinct #######################

v2012prec <- read.csv(file= "state_g12_voters_by_g12_rgprec.csv", header=TRUE, sep=",", na.strings=c("NA"))

# Keep variables of interest
v2012prec <- v2012prec[, c("RGPREC_KEY", "TOTREG_R")]
nrow(v2012prec)

names(v2012prec)[names(v2012prec)=="TOTREG_R"] <-"voters"

# merge files together
v2012reg <- merge(p2bmap, v2012prec, by="RGPREC_KEY", all.x=TRUE)
nrow(v2012reg)

#Calculate the percent of registered voters that did not vote by block
v2012reg$BLKNOVOTE = v2012reg$BLKREG -v2012reg$PCTRGPREC/100*v2012reg$voters

# Create census tract ID
# Pad leading zeros for a fixed length of 6 characters
v2012reg$ct6 <-sprintf("%06d", v2012reg$TRACT)
v2012reg$FIPS2 <- paste0(v2012reg$FIPS,v2012reg$ct6)

# Aggregate and create a new file
v2012ct <-aggregate(v2012reg[,c("BLKREG", "BLKNOVOTE")], by=list(v2012reg$FIPS2), FUN=sum, na.rm=TRUE)

# Keep variables of interest
names(v2012ct)[names(v2012ct)=="Group.1"] <-"FIPS"
names(v2012ct)[names(v2012ct)=="BLKNOVOTE"] <-"numerator"
names(v2012ct)[names(v2012ct)=="BLKREG"] <-"denominator"


# Merge with reference census tracts
# Read reference tracts
# hdi_ct <- read.csv(file= "hdi_ref_ct.csv", header=TRUE, sep=",", na.strings=c("NA"))

hdi <- merge(hdi_ct, v2012ct, by="FIPS", all.x=TRUE)


# Calculate percent and standard error and relative standard error
hdi$percent = 100*hdi$numerator/hdi$denominator
hdi$se_pct   = sqrt(hdi$percent*(100-hdi$percent)/hdi$denominator)
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)


summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file
names(hdi)[names(hdi)=="denominator"] <- "novoter12_d"
names(hdi)[names(hdi)=="numerator"]   <- "novoter12_n"
names(hdi)[names(hdi)=="percent"]     <- "novoter12_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "novoter12_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "novoter12_rse"
names(hdi)[names(hdi)=="pctile"]      <- "novoter12_pctile"

#Label files with indicator, source, and version
#Label files with indicator, source, and version
hdi$indicator <- "Percentage of registered voters not voting in the 2012 general election"
hdi$reportyear <-"2012"
hdi$source <- "UC Berkeley Statewide Database"
hdi$version <- today

# Save variable of interest and order variables
novoter12 <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "novoter12_n", "novoter12_d","novoter12_pct", "novoter12_se_pct", "novoter12_rse", "novoter12_pctile", "source", "version")]

# Write out datafile
write.csv(novoter12,"hdi_novoter12.csv", row.names=FALSE)



####################### Parks #######################

# Read source file from CDPH/HCI
hdi <- read.csv(file= "ParkBeachOpen2010.csv", head=TRUE, sep=",", na.strings=c("NA"))

# Save variable of interest and order variables
hdi <- hdi[,c("geotypevalue","county_fips", "pop2010", "pop_park_acc","p_parkacc", "se")]

# Rename variables of interest
names(hdi)[names(hdi)=="pop2010"] <-"denominator"
names(hdi)[names(hdi)=="pop_park_acc"] <-"numerator"
names(hdi)[names(hdi)=="p_parkacc"] <-"percent"
names(hdi)[names(hdi)=="se"] <-"se_pct"

# Create 10 digit census tract identifier from geotypealue and county_fips
substrRight <- function(x, n){
  substr(x, nchar(x)-n+1, nchar(x))
}
hdi$ct6 <-substrRight(as.character(hdi$geotypevalue), 6)
hdi$FIPS <- paste0(hdi$county_fips,hdi$ct6)

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Flip the proportion to percent without park access
hdi$percent = 100*(1-hdi$percent)
hdi$se_pct = 100*hdi$se_pct 

# Calculate percent and standard error and relative standard error
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)


# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file
names(hdi)[names(hdi)=="denominator"] <- "parks_d"
names(hdi)[names(hdi)=="numerator"]   <- "parks_n"
names(hdi)[names(hdi)=="percent"]     <- "parks_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "parks_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "parks_rse"
names(hdi)[names(hdi)=="pctile"]      <- "parks_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of the population not living within a half-mile of a park, beach, or open space greater than 1 acre"
hdi$reportyear <-"2010"
hdi$source <- "HCI/CaLANDS Database"
hdi$version <- today

# Save variable of interest and order variables
parks <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "parks_n", "parks_d","parks_pct", "parks_se_pct", "parks_rse", "parks_pctile", "source", "version")]

# Write out datafile
write.csv(parks,"hdi_parks.csv", row.names=FALSE)

################ Severe and Fatal Injuries #######################

rti <- read.csv(file= "HCI_RoadTrafficInjuries_753_CT_PL_CO_RE_R4_CA-12-17-13_A-Y.csv ", header=TRUE, sep=",", na.strings=c("NA"))

# Keep variables of interest
rti <- rti[, c("geotypevalue", "injuries", "totalpop", "poprate")]
nrow(rti)

names(rti)[names(rti)=="geotypevalue"] <-"FIPS"
names(rti)[names(rti)=="injuries"] <-"numerator"
names(rti)[names(rti)=="totalpop"] <-"denominator"
names(rti)[names(rti)=="poprate"] <-"percent"

# create unique population file
# minimum poverty rate
rtipop <- rti[, c("FIPS", "denominator")]

rtipop <- rtipop[order(rti$FIPS,rti$denominator),]
pop_ct <- rtipop[!duplicated(rtipop$FIPS),]
nrow(pop_ct)

# Save the population file
rtipop <- rti[, c("FIPS", "denominator")]

# aggregate injuries and population rate
inj <-aggregate(rti,by=list(rti$FIPS), FUN=sum, na.rm=TRUE)
nrow(inj)

# Keep variables of interest
names(inj)[names(inj)=="Group.1"] <-"FIPS"
inj <- inj[, c("FIPS", "numerator","percent")]

# Merge the population and injury files
hdi <- merge(inj,pop_ct, by="FIPS", all=TRUE)

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Set census tracts without injutries to 0
hdi$numerator[is.na(hdi$numerator)] <- 0
hdi$percent[is.na(hdi$percent)] <- 0
hdi$denominator[which(is.na(hdi$denominator))] <-hdi$pop2010

# Calculate percent and standard error and relative standard error
hdi$se_pct = sqrt(hdi$numerator)/hdi$denominator * 100000
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
# hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
# hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)


summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file
names(hdi)[names(hdi)=="denominator"] <- "pedshurt_d"
names(hdi)[names(hdi)=="numerator"]   <- "pedshurt_n"
names(hdi)[names(hdi)=="percent"]     <- "pedshurt_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "pedshurt_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "pedshurt_rse"
names(hdi)[names(hdi)=="pctile"]      <- "pedshurt_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "5-year (2006-2010) annual average rate of severe and fatal pedestrian injuries per 100,000 population"
hdi$reportyear <-"2006-2010"
hdi$source <- "HCI/SWITRS"
hdi$version <- today

# Save variable of interest and order variables
pedshurt <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "pedshurt_n", "pedshurt_d","pedshurt_pct", "pedshurt_se_pct", "pedshurt_rse", "pedshurt_pctile", "source", "version")]

# Write out datafile
write.csv(pedshurt,"hdi_pedshurt.csv", row.names=FALSE)


####################### Supermrkt #######################

# Read source file from USDA/ERS/Food AccesResearch Atlas, 2013
hdi <- read.csv(file= "CA_food availability_DataDownload.csv", head=TRUE, sep=",", na.strings=c("NA"))

# Save variable of interest and order variables
hdi <- hdi[,c("CensusTract","lapop1", "POP2010", "lapop1share")]

# Rename variables of interest
names(hdi)[names(hdi)=="POP2010"] <-"denominator"
names(hdi)[names(hdi)=="lapop1"] <-"numerator"
names(hdi)[names(hdi)=="lapop1share"] <-"percent"
names(hdi)[names(hdi)=="CensusTract"] <-"FIPS"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percent and standard error and relative standard error
hdi$percent = 100*hdi$percent
hdi$se_pct = sqrt(hdi$percent*(100-hdi$percent)/hdi$denominator)
hdi$rse = 100*hdi$se_pct/hdi$percent

# Reverse percent for percents >50 in rse calculation
hdi$rse2 = 100*hdi$se_pct/(100-hdi$percent)
hdi$rse <- ifelse(hdi$percent < 50, hdi$rse,hdi$rse2)

# Reassign infinite values of rse to large value 1000
hdi$rse = replace(hdi$rse,hdi$rse ==Inf, 1000)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file
names(hdi)[names(hdi)=="denominator"] <- "supermrkt_d"
names(hdi)[names(hdi)=="numerator"]   <- "supermrkt_n"
names(hdi)[names(hdi)=="percent"]     <- "supermrkt_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "supermrkt_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "supermrkt_rse"
names(hdi)[names(hdi)=="pctile"]      <- "supermrkt_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Percentage of the population living more than one mile from a supermarket or large grocery store"
hdi$reportyear <-"2010"
hdi$source <- "USDA_ERS_FOOD_ACCESS_RESERACH_ATLAS2013"
hdi$version <- today

# Save variable of interest and order variables
supermrkt <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "supermrkt_n", "supermrkt_d","supermrkt_pct", "supermrkt_se_pct", "supermrkt_rse", "supermrkt_pctile", "source", "version")]

# Write out datafile
write.csv(supermrkt,"hdi_supermrkt.csv", row.names=FALSE)

################  Retail ##############################################
############### Read California Smart Location Database ###############

sld <- read.csv(file= "SmartLocationDb2010CA.csv", header=TRUE, sep=",", na.strings=c("NA"))

# Keep variables of interest
sld <- sld[, c("GEOID10", "AC_UNPR", "D1C8_Ret10", "D1C8_Ent10", "D1C8_Ed10")]
nrow(sld)

# Sum up density for retail, entertainment and education and 
# ccaclulate jobs per census block group
sld$retail <- sld$D1C8_Ret10 + sld$D1C8_Ent10 + sld$D1C8_Ed10
sld$jobs <- sld$retail*sld$AC_UNPR

# Create census tract ID
sld$FIPS <- as.numeric(substr(as.character(sld$GEOID10),1,10))

# Aggregate and create a new file at level of censuis tract
sld_ct <-aggregate(sld[,c("jobs","AC_UNPR")],by=list(sld$FIPS), FUN=sum, na.rm=TRUE)

# Create percent from ratio of jobs to acres
sld_ct$percent = sld_ct$jobs/sld_ct$AC_UNPR

# Keep variables of interest
names(sld_ct)[names(sld_ct)=="Group.1"] <-"FIPS"
names(sld_ct)[names(sld_ct)=="jobs"] <-"numerator"
names(sld_ct)[names(sld_ct)=="AC_UNPR"] <-"denominator"

# Merge with reference census tracts

hdi <- merge(hdi_ct, sld_ct, by="FIPS", all.x=TRUE)

# Calculate percent and standard error and relative standard error
hdi$se_pct   <- NA
hdi$rse      <- NA 


# Calculate percentile, ties are averaged
hdi$pctile = 100*(1 - rank(hdi$percent)/NROW(na.omit(hdi$percent)))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)

summary(hdi$rse)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file
names(hdi)[names(hdi)=="denominator"] <- "retail_d"
names(hdi)[names(hdi)=="numerator"]   <- "retail_n"
names(hdi)[names(hdi)=="percent"]     <- "retail_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "retail_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "retail_rse"
names(hdi)[names(hdi)=="pctile"]      <- "retail_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Gross retail, entertainment, and education employment density (jobs/acre) on unprotected land"
hdi$reportyear <-"2010"
hdi$source <- "EPA Smart Location Database"
hdi$version <- today

# Save variable of interest and order variables
retail <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "retail_n", "retail_d","retail_pct", "retail_se_pct", "retail_rse", "retail_pctile", "source", "version")]

# Write out datafile
write.csv(retail,"hdi_retail.csv", row.names=FALSE)


################  Transit ##############################################
############### Read California Smart Location Database ###############

sld <- read.csv(file= "SmartLocationDb2010CA.csv", header=TRUE, sep=",", na.strings=c("NA"))

# Keep variables of interest, D4c is transit frequency (vehicles/hour)
sld <- sld[, c("GEOID10", "D4c")]
nrow(sld)

# Create census tract ID
sld$FIPS <- as.numeric(substr(as.character(sld$GEOID10),1,10))

# Aggregate and create a new file
sld_ct <-aggregate(sld$D4c,by=list(sld$FIPS), FUN=mean, na.rm=TRUE)

# Keep variables of interest
names(sld_ct)[names(sld_ct)=="Group.1"] <-"FIPS"
names(sld_ct)[names(sld_ct)=="x"] <-"percent"
# Missing block groups coded to -9999 in SLD 
# a few census tracts with missing block group data were coded to NA
sld_ct$percent = replace(sld_ct$percent, sld_ct$percent < 0,NA)

# Merge with reference census tracts
hdi <- merge(hdi_ct, sld_ct, by="FIPS", all.x=TRUE)

# Calculate percent and standard error and relative standard error
hdi$numerator   <- hdi$percent
hdi$denominator <- NA
hdi$se_pct   <- NA
hdi$rse      <- NA 

# Calculate percentile, ties are averaged
hdi$pctile = 100*(1 - rank(hdi$percent)/NROW(na.omit(hdi$percent)))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile < 0, NA)


# summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file
names(hdi)[names(hdi)=="denominator"] <- "transit_d"
names(hdi)[names(hdi)=="numerator"]   <- "transit_n"
names(hdi)[names(hdi)=="percent"]     <- "transit_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "transit_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "transit_rse"
names(hdi)[names(hdi)=="pctile"]      <- "transit_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Aggregate frequency of transit service within 0.25 miles of block group boundary per hour during evening peak period"
hdi$reportyear <-"2010"
hdi$source <- "EPA Smart Location Database"
hdi$version <- today

# Save variable of interest and order variables
transit <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "transit_n", "transit_d","transit_pct", "transit_se_pct", "transit_rse", "transit_pctile", "source", "version")]

# Write out datafile
write.csv(transit,"hdi_transit.csv", row.names=FALSE)


################### yll: Years of Life Lost per Capita ################
# Read VCU file
hdi <- read.csv(file= "yll.csv", head=TRUE, sep=",", na.strings=c("NA"))

names(hdi)[names(hdi)=="yll"] <-"percent"

# Merge with reference census tracts
hdi <- merge(hdi_ct, hdi,by="FIPS", all.x=TRUE)

# Calculate percent and standard error and relative standard error
hdi$numerator  <- NA
hdi$denominator <- NA
hdi$se_pct     <- NA
hdi$rse <- NA

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent)) 
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)


# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file

names(hdi)[names(hdi)=="denominator"] <- "yll_d"
names(hdi)[names(hdi)=="numerator"]   <- "yll_n"
names(hdi)[names(hdi)=="percent"]     <- "yll_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "yll_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "yll_rse"
names(hdi)[names(hdi)=="pctile"]      <- "yll_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Years of life lost per capita"
hdi$reportyear <-"2010"
hdi$source <- "Virginia Commonwealth University"
hdi$version <- today

yll <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "yll_n", "yll_d","yll_pct", "yll_se_pct", "yll_rse", "yll_pctile", "source", "version")]

# Write out datafile
write.csv(yll, "hdi_yll.csv", row.names=FALSE)


###################### Tree Canopy ############################
# Read source file from CDPH/HCI
hdi <- read.csv(file= "BRACE_TreeCanopy_458_CT_PL_CO_RE_CA__02DEC15.csv", head=TRUE, sep=",", na.strings=c("NA"))

# Save variable of interest and order variables
hdi <- hdi[,c("geotypevalue","percent","percent_se", "percent_rse")]

# Rename variables of interest
names(hdi)[names(hdi)=="percent_se"] <-"se_pct"
names(hdi)[names(hdi)=="percent_rse"] <-"rse"
names(hdi)[names(hdi)=="geotypevalue"] <-"FIPS"

# Merge with valid census tracts
hdi <- merge(hdi, hdi_ct, by="FIPS", all.y = TRUE)

# Calculate percentile, ties are averaged
hdi$pctile = 100*rank(hdi$percent)/NROW(na.omit(hdi$percent))
NROW(na.omit(hdi$percent))
hdi$pctile <- replace(hdi$pctile, hdi$pctile > 100, NA)


summary(hdi$rse)

# Look at summary statistics including missing values
summary(hdi$percent)

# inspect file
head(hdi)
tail(hdi)

# Keep variables of interest write out file
names(hdi)[names(hdi)=="denominator"] <- "treecanopy_d"
hdi$treecanopy_d   <- NA
hdi$treecanopy_n   <- NA
names(hdi)[names(hdi)=="percent"]     <- "treecanopy_pct"
names(hdi)[names(hdi)=="se_pct"]      <- "treecanopy_se_pct"
names(hdi)[names(hdi)=="rse"]         <- "treecanopy_rse"
names(hdi)[names(hdi)=="pctile"]      <- "treecanopy_pctile"

#Label files with indicator, source, and version
hdi$indicator <- "Population-weighted proportion of the census tract lacking tree canopy"
hdi$reportyear <- "2011"
hdi$source <- "HCI/National Land Cover Database"
hdi$version <- today

# Save variable of interest and order variables
treecanopy <- hdi[,c("indicator","reportyear","FIPS","County_Name","County_FIPS", "treecanopy_n", "treecanopy_d","treecanopy_pct", "treecanopy_se_pct", "treecanopy_rse", "treecanopy_pctile", "source", "version")]

# Write out datafile
write.csv(treecanopy,"hdi_treecanopy.csv", row.names=FALSE)

