# hdi_score1-17-16.R  N Maizlish  1/17/2016
# Reads 27 standardized HDI indicator files from HDI Indicatormm-dd-yyy.R
# and assesses missing data, imputes missing values using Amelia
# multiple imputation package, calculates the HDI domain and total score
# adds additional geographic fields and outputs a standard HDI file
# for mapping
# Indicators are expressed as percentages or rates and percentile 
# rankings are expressed from 0 to 100 (least to most disadvantaged)

# set working directory
# You will need to change setwd to match your computers file system
setwd ("")

# Get todays date to assign version
today <- date()

# turn off scientific notation and console output wide
options(scipen=999)
options(width=300)

master <-""
master2<-""

# Set file/variable prefixes and extensions
ext <- ".csv"
prfx <- "hdi_"
vext <-"_pct"

# List of files/variables
flist <- c("asthma", "costburden", "crowded", "disability", "income", "noauto", "noenglish", "nohighschl", "nokitchen", "notinhiscl", "notinprscl", "nowork", "poverty", "renters", "singlparnt", "uninsured", "lbw", "pm25", "traffic", "novoter10", "novoter12", "parks", "pedshurt", "supermrkt", "retail", "transit", "treecanopy", "yll")

fname <-paste0(prfx,flist,ext)
vname <-paste0(flist,vext)
fname
vname

# read in stub file of valid census tracts
hdi <- read.csv(file="hdi_ref_ct.csv",header=TRUE,sep=",",stringsAsFactors=FALSE)

# Keep variables of interest
# hdi <- as.data.frame(hdi$FIPS)
# names(hdi)[names(hdi)=="hdi$FIPS"] <-"FIPS"

########################### START Loop1 #################################

# Read files
for(i in 1:length(fname)){
hdi2 <- read.csv(file=fname[i],header=TRUE, sep=",",stringsAsFactors=FALSE)

# Keep variables of interest
hdi2 <- hdi2[,c("FIPS", vname[i])]

# Merge files
hdi<-merge(hdi,hdi2,by="FIPS",all.x=TRUE)

# Count missing data
  misscnt  <- 7794 - NROW(na.omit(hdi2))
  missname <-vname[i]
  master <- rbind(master,misscnt)
  master2 <-rbind(master2,missname)
}
########################### END Loop1 ##################################


################### Analysis of Missing Data ###########################

master <- cbind(master2,master)

# Total complete cases
NROW(na.omit(hdi))

#Total missing cases
NROW(hdi) - NROW(na.omit(hdi))

# Write Out Missing Data Table (Table 8)
write.csv(master,"misstable.csv")


# Write out file with name hdiYYYY-MM-DDmissing.csv
write.csv(hdi, paste0("hdi",format(Sys.time(), "%Y-%m-%d"), "missing.csv"), row.names=FALSE)

# Create a missing value matrix (0=non-missing, 1 = missing)
hdim <- ifelse(is.na(hdi[,6:33]),1,0)
hdim <- cbind(hdi[,1:5],hdim)

# Sum up rows for missing variable per census tract
varmiss <-as.data.frame(rowSums(hdim[,6:33]))
missct <-table(varmiss)
missct

# Domain missing
#Economic
hdim$econmiss <- ifelse(hdim$costburden_pct >0 | hdim$crowded_pct >0 | hdim$income_pct >0 | hdim$noauto_pct > 0 | hdim$nokitchen_pct > 0 | hdim$nowork_pct> 0 | hdim$poverty_pct > 0 | hdim$uninsured_pct > 0, 1, NA)
table(hdim$econmiss)

#Education
hdim$educmiss <- ifelse(hdim$notinhiscl_pct >0 | hdim$notinprscl_pct >0, 1, NA)
table(hdim$educmiss)

#Environment
hdim$envimiss <- ifelse(hdim$pedshurt_pct >0 | hdim$pm25_pct >0 | hdim$traffic_pct >0, 1, NA)
table(hdim$envimiss)

#Health
hdim$healmiss <- ifelse(hdim$asthma_pct >0 | hdim$disability_pct >0 | hdim$lbw_pct >0 | hdim$yll_pct> 0, 1, NA)
table(hdim$healmiss)

#Neighborhoods - treecanopy
hdim$neigmiss <- ifelse(hdim$parks_pct >0 | hdim$retail_pct >0 | hdim$supermrkt_pct >0 | hdim$treecanopy_pct > 0, 1, NA)
table(hdim$neigmiss)

#########  Unpound this command for transit missing data analysis  #####
#Neighborhoods - transit (use this only for data quality assessment)
# hdim$neigmiss <- ifelse(hdim$parks_pct >0 | hdim$retail_pct >0 | hdim$supermrkt_pct >0 | hdim$transit_pct > 0, 1, NA)
# table(hdim$neigmiss)

#Social
hdim$socimiss <- ifelse(hdim$noenglish_pct >0 | hdim$nohighschl_pct >0 | hdim$novoter10_pct >0 | hdim$novoter12_pct > 0 | hdim$renters_pct > 0 | hdim$singlparnt_pct> 0, 1, NA)
table(hdim$socimiss)

# Add to hdi for additional analyses
hdi <- cbind(hdi,varmiss)
colnames(hdi)[34] <- "nctmiss"

# Create variable for census tract with any missing data
hdi$ctmiss = ifelse(hdi$nctmiss ==0,0,1)

# read urban/rural look-up table from 2010 census
urb <- read.csv(file="UrbanPlacesCensusTracts2010Lookup.csv",header=TRUE,sep=",",stringsAsFactors=FALSE)

# Keep variables of interest
urb <- urb[,c("FIPS", "UrbanType")]

# Merge files
hdi<-merge(hdi,urb,by="FIPS",all.x=TRUE)

# create urban rural variable
hdi$urban <-ifelse(hdi$UrbanType =="rural",0,1)

Ctab <-table(hdi$ctmiss,hdi$urban, dnn=c("Missing 0=N, 1=Y","Urban (0=R, 1=U"))
Ctab
prop.table(Ctab,2)
summary(Ctab)

# read county to region look-up table from 2010 census
reg <- read.csv(file="CA_County_FIPS2Region2010.csv",header=TRUE,sep=",",stringsAsFactors=FALSE)

# Keep variables of interest
reg <- reg[,c("County_FIPS", "Region_name")]

# Merge files
hdi<-merge(hdi,reg,by="County_FIPS",all.x=TRUE)

# Tabulate missing data by region
Ctabreg <-table(hdi$Region_name, hdi$ctmiss, dnn=c("Region", "Missing 0=N 1=Y"))
Ctabreg
prop.table(Ctabreg,1)
summary(Ctabreg)


###################### Read Files for Imputation ########################

# Drop ineligible census tract and drop transit variable
hdi <- subset(hdi,FIPS != 6037930401)
hdi <- subset(hdi,select = -c(transit_pct))
# Add original row numbers as X for later merging
hdi$X <- as.numeric(rownames(hdi))

# Correlate variables
# Select only numeric variables
hdicor <- subset(hdi, select=c(asthma_pct:yll_pct))
cortab <-cor(hdicor, use= "pairwise.complete.obs")

# percent variables using logistic transformation
hdiimp <- hdi[,c("costburden_pct", "crowded_pct", "disability_pct", "noauto_pct","noenglish_pct", "nohighschl_pct", "nokitchen_pct", "poverty_pct","nowork_pct", "notinprscl_pct", "notinhiscl_pct", "lbw_pct", "renters_pct", "singlparnt_pct", "uninsured_pct", "novoter10_pct", "novoter12_pct", "parks_pct","treecanopy_pct")]

# express as proportions for imputation with logistic transformation
hdiimp <-hdiimp[,1:19]/100

# Note: supermrkt_pct refuses to be transformed below and is not used
# is it an auxillary variable with no missing data

# Add/substract from 0/1 for logistic transformation for all percent variables

hdiimp[hdiimp==0] <- 0.0001
hdiimp[hdiimp==1] <- 0.9999

# Each time Amelia is run a different imputed file is generated
# No two imputed files will be exactly the same
# Multiple runs on the same day will overwrite files

library(Amelia)

# Transformed for percents, 5 iterations
a.out <- amelia(x=hdiimp, m=5, lgstc = TRUE)

write.amelia(a.out,separate=TRUE,"hdi_outdata",extension=".csv",format="csv")
a.out5 <- read.csv(file="hdi_outdata5.csv", header=TRUE, sep=",", na.strings="NA")

# Add back the delta for the transformation
a.out5[a.out5==0.0001] <- 0
a.out5[a.out5==0.9999] <- 1

summary(a.out5$notinprscl_pct)
summary(hdi$notinprscl_pct)
sd(a.out5$notinprscl_pct)
sd(hdi$notinprscl_pct, na.rm=TRUE)

summary(a.out5$notinhiscl_pct)
summary(hdi$notinhiscl_pct)
sd(a.out5$notinhiscl_pct)
sd(hdi$notinhiscl_pct, na.rm=TRUE)

#Convert proportions back to percents
a.out5temp <- a.out5[,2:20]*100
a.out5 <- cbind(a.out5$X,a.out5temp)
names(a.out5)[names(a.out5)=="a.out5$X"] <-"X"


# quantitative variables without a transformation and auxillary
# with strong correlations > 0.3 with yll and others

hdiimp <- hdi[,c("asthma_pct", "pm25_pct", "income_pct", "pedshurt_pct","retail_pct", "yll_pct", "nohighschl_pct", "poverty_pct","nowork_pct", "singlparnt_pct", "disability_pct","traffic_pct")]

# convert percentages to proportions
hdiimp2 <- hdiimp[,7:11]/100
# select quantitative variables
hdiimp3 <- hdi[,c("asthma_pct", "pm25_pct", "income_pct", "pedshurt_pct","retail_pct", "yll_pct", "traffic_pct")]
# add back all variables
hdiimp <- cbind(hdiimp2,hdiimp3)

b.out <- amelia(x=hdiimp, m=5)

write.amelia(b.out,separate=TRUE,"hdib_outdata",extension=".csv",format="csv")
b.out5 <- read.csv(file="hdib_outdata5.csv", header=TRUE, sep=",", na.strings="NA")

summary(b.out5$yll_pct)
summary(hdi$yll_pct)
sd(b.out5$yll_pct)
sd(hdi$yll_pct, na.rm=TRUE)

summary(b.out5$pm25_pct)
summary(hdi$pm25_pct)
sd(b.out5$pm25_pct)
sd(hdi$pm25_pct, na.rm=TRUE)


# Combine the imputed data into a single file
b.out5 <-b.out5[,c("X","asthma_pct","pm25_pct","income_pct","traffic_pct","pedshurt_pct","retail_pct","yll_pct")]

# merge files
hdi7793 <- merge(hdi[,c("FIPS","X","supermrkt_pct")],a.out5, by="X", all.x=TRUE)

hdi7793 <- merge(hdi7793,b.out5, by="X", all.x=TRUE)

# Add version
hdi7793$version = today

# Write out file with name hdiYYYY-MM-DDimputed.csv
write.csv(hdi7793, paste0("hdi",format(Sys.time(), "%Y-%m-%d"), "imputed.csv"), row.names=FALSE)

############################ Calculate HDI Score ########################

# Variable suffixes
zext <-"_z_cns"
iext <-"_pctile"
zname <-paste0(flist,zext)
iname <-paste0(flist,iext)

# Data set with valid census tracts and imputed missing data
hdi <- hdi7793

# Flip sign for income and retail
negsign <- -1
hdi$income_pct <- hdi$income_pct*negsign
hdi$retail_pct <- hdi$retail_pct*negsign

########################### START Loop2 #################################
# delete transit from variable list
vname <- vname[vname != "transit_pct"]
zname <- zname[zname != "transit_z_cns"]
iname <- iname[iname != "transit_pctile"]

# Read HDI file and calculate Z score
for(i in 1:length(zname)){

# Keep variables of interest
hdi$mean <- mean(hdi[,c(vname[i])])
hdi$sd   <- sd(hdi[,c(vname[i])])

hdi[,c(zname[i])] <- (hdi[,c(vname[i])] - hdi$mean)/hdi$sd 

# Constrain the z score between 0 and 5
  hdi[,c(zname[i])] <- ifelse (hdi[,c(zname[i])]<0,0, hdi[,c(zname[i])])
  hdi[,c(zname[i])] <- ifelse (hdi[,c(zname[i])]>5,5, hdi[,c(zname[i])])
  
# Calculate the percentile
hdi[,c(iname[i])]  <- 100*rank(hdi[,c(vname[i])])/NROW(hdi[,c(vname[i])])
}
########################### END Loop2 ##################################

# Flip sign back income and retail
hdi$income_pct <- hdi$income_pct*negsign
hdi$retail_pct <- hdi$retail_pct*negsign

# Calculate domain scores

# Economic domain mean score
hdi$economic <- (hdi$costburden_z_cns + hdi$crowded_z_cns + hdi$income_z_cns + hdi$noauto_z_cns + hdi$nokitchen_z_cns + hdi$nowork_z_cns + hdi$poverty_z_cns + hdi$uninsured_z_cns)/8 

# Calculate Economic Percentile (0 least - 100 most disadvantaged)
hdi$economic_pctile <- 100*rank(hdi$economic)/NROW(hdi$economic)

#Education domain mean score 
hdi$education <- (hdi$notinhiscl_z_cns + hdi$notinprscl_z_cns)/2 

# Calculate Education Percentile (0 least - 100 most disadvantaged)
hdi$education_pctile <- 100*rank(hdi$education)/NROW(hdi$education)

#Environment domain mean score 
hdi$environment <- (hdi$pedshurt_z_cns + hdi$pm25_z_cns + hdi$traffic_z_cns)/3 

# Calculate Environment Percentile (0 least - 100 most disadvantaged)
hdi$environment_pctile <- 100*rank(hdi$environment)/NROW(hdi$environment)

#Health domain mean score 
hdi$health <- (hdi$asthma_z_cns + hdi$disability_z_cns + hdi$lbw_z_cns + hdi$yll_z_cns)/4 

# Calculate Health Percentile (0 least - 100 most disadvantaged)
hdi$health_pctile <- 100*rank(hdi$health)/NROW(hdi$health)

#Neighborhoods domain mean score 
hdi$neighborhood <- (hdi$parks_z_cns + hdi$retail_z_cns + hdi$supermrkt_z_cns + hdi$treecanopy_z_cns)/4 

# Calculate Neighborhood Percentile (0 least - 100 most disadvantaged)
hdi$neighborhood_pctile <- 100*rank(hdi$neighborhood)/NROW(hdi$neighborhood)

#Social domain mean score 
hdi$social <- (hdi$noenglish_z_cns + hdi$nohighschl_z_cns + hdi$novoter10_z_cns + hdi$novoter12_z_cns + hdi$renters_z_cns + hdi$singlparnt_z_cns)/6 

# Calculate Social Percentile (0 least - 100 most disadvantaged)
hdi$social_pctile <- 100*rank(hdi$social)/NROW(hdi$social)

# HDI total: 50% Econ + 15% Social + 10% Education + 10% Health + 
# 10% Environment + 5% Neighborhoods
hdi$hdi_total <- 0.5*hdi$economic + 0.15*hdi$social + 0.1*hdi$education + 0.1*hdi$health + 0.1*hdi$environment + 0.05* hdi$neighborhood 

# Calculate Overall Percentile (0 least - 100 most disadvantaged)
hdi$hdi_pctile <- 100*rank(hdi$hdi_total)/NROW(hdi$hdi_total)

# Create quintiles of the HDI distribution
hdi$quintiles <-cut(hdi$hdi_pctile,breaks=c(0,20,40,60,80,101),labels=c("1st","2nd","3rd","4th","5th"), right=FALSE)

# Create quartiles with 1st (least) and 4th (most) disadvantaged
hdi$quartiles <-cut(hdi$hdi_pctile,breaks=c(0,25,50,75,101), labels=c("1st","2nd","3rd","4th"),right=FALSE)

# Create top 25% census tracts variable of HDI and Poverty
hdi$hdi_top25pct <- ifelse(hdi$hdi_pctile > 75,"Yes","No")
hdi$poverty_top25pct  <- ifelse(hdi$poverty_pctile > 75,"Yes","No")

# Write out file
# Data Quality Check: write full file with name hdiYYYY-MM-DDscore.csv
write.csv(hdi, paste0("hdi",format(Sys.time(), "%Y-%m-%d"), "pct_z_tile.csv"), row.names=FALSE)

# Save variables of interest, rename, and reorder file
names(hdi)[names(hdi)=="FIPS"] <-"CensusTract"
names(hdi)[names(hdi)=="asthma_pct"] <-"asthma"
names(hdi)[names(hdi)=="costburden_pct"] <-"costburden"
names(hdi)[names(hdi)=="crowded_pct"] <-"crowded"
names(hdi)[names(hdi)=="disability_pct"] <-"disability"
names(hdi)[names(hdi)=="income_pct"] <-"income"
names(hdi)[names(hdi)=="lbw_pct"] <-"lbw"
names(hdi)[names(hdi)=="noauto_pct"] <-"noauto"
names(hdi)[names(hdi)=="noenglish_pct"] <-"noenglish"
names(hdi)[names(hdi)=="nohighschl_pct"] <-"nohighschl"
names(hdi)[names(hdi)=="nokitchen_pct"] <-"nokitchen"
names(hdi)[names(hdi)=="notinhiscl_pct"] <-"notinhiscl"
names(hdi)[names(hdi)=="notinprscl_pct"] <-"notinprscl"
names(hdi)[names(hdi)=="novoter10_pct"] <-"novoter10"
names(hdi)[names(hdi)=="novoter12_pct"] <-"novoter12"
names(hdi)[names(hdi)=="nowork_pct"] <-"nowork"
names(hdi)[names(hdi)=="poverty_pct"] <-"poverty"
names(hdi)[names(hdi)=="parks_pct"] <-"parks"
names(hdi)[names(hdi)=="pedshurt_pct"] <-"pedshurt"
names(hdi)[names(hdi)=="pm25_pct"] <-"pm25"
names(hdi)[names(hdi)=="renters_pct"] <-"renters"
names(hdi)[names(hdi)=="retail_pct"] <-"retail"
names(hdi)[names(hdi)=="singlparnt_pct"] <-"singlparnt"
names(hdi)[names(hdi)=="supermrkt_pct"] <-"supermrkt"
names(hdi)[names(hdi)=="traffic_pct"] <-"traffic"
names(hdi)[names(hdi)=="treecanopy_pct"] <-"treecanopy"
names(hdi)[names(hdi)=="uninsured_pct"] <-"uninsured"
names(hdi)[names(hdi)=="yll_pct"] <-"yll"


# To reproduce 1-17-16 version (1-2-16 data) of HDI 1.10 
# use the following block because
# Amelia imputation will create a slightly different file each time
# its is run - there is no seed value to force it to produce
# the same imputed values. 
# For future updates of the HDI, comment out executable lines in block 

####################################################################
hdi<- NA
# Read HDI hdi2016-01-02score.csv
hdi <- read.csv(file= "hdi2016-01-02score.csv", head=TRUE, sep=",", na.strings=c("NA"))
# Drop duplicate variables
hdi<-hdi[,-c(2:7,79:92)]
# Create quartiles with 1st (least) and 4th (most) disadvantaged
hdi$quartiles <-cut(hdi$hdi_pctile,breaks=c(0,25,50,75,101), labels=c("1st","2nd","3rd","4th"),right=FALSE)

####################################################################

# Additional variables for group quarters, city, urban/rural, CalEnviroScreen, quintiles of the HDI score, quintiles of the CES2 score, top 25% of HDI, CES2Scores, and Poverty scores, agreement/disagreement between HDI1.1 and CES2 
# add back rows for ineligible census tracts (total rows = 8057)

# Read group quarters file
# set working directory
setwd ("")

#################### Total Population and Group Quarters ################
# Read 2010 Decennial DP01 source file
header <- read.csv(file= "DEC_10_DP_DPDP1.csv", nrows=1, header=FALSE, sep=",", stringsAsFactors = FALSE)
dp01 <- read.csv(file= "DEC_10_DP_DPDP1.csv", skip=2, header=FALSE, sep=",")
colnames(dp01) <- unlist(header)

# Keep variables of interest
dp01 <- dp01[, c("GEO.id2", "HD01_S001","HD02_S143")]

names(dp01)[names(dp01)=="GEO.id2"] <-"CensusTract"
names(dp01)[names(dp01)=="HD01_S001"] <-"pop2010"
names(dp01)[names(dp01)=="HD02_S143"] <-"pct2010gq"
dp01$County_FIPS <- as.numeric(substr(dp01$CensusTract,1,4))


############## City Associated with Census Tract Centroid #############
# Read look-up file
ct2city <- read.csv(file= "census_tracts2_place_look-up_table.csv",header=TRUE, sep=",",stringsAsFactors=FALSE)

# Keep variables of interest
ct2city <- ct2city [, c("ct10", "NAME10")]

names(ct2city)[names(ct2city)=="ct10"] <-"CensusTract"
names(ct2city)[names(ct2city)=="NAME10"] <-"City"


#################### County Name ################
# read county name look-up table 
county <- read.csv(file="CA_County_FIPS2010.csv",header=TRUE,sep=",",stringsAsFactors=FALSE)

# Keep variables of interest
county <- county[,c("County_FIPS", "County_Name")]


############## City Associated with Census Tract Centroid #############
# Read look-up file
ct2city <- read.csv(file= "census_tracts2_place_look-up_table.csv",header=TRUE, sep=",",stringsAsFactors=FALSE)

# Keep variables of interest
ct2city <- ct2city [, c("ct10", "NAME10")]

names(ct2city)[names(ct2city)=="ct10"] <-"CensusTract"
names(ct2city)[names(ct2city)=="NAME10"] <-"City"


# read urban/rural look-up table from 2010 census
urb <- read.csv(file="UrbanPlacesCensusTracts2010Lookup.csv",header=TRUE,sep=",",stringsAsFactors=FALSE)

names(urb)[names(urb)=="FIPS"] <-"CensusTract"

# Keep variables of interest
urb <- urb[,c("CensusTract", "UrbanType")]

############## Race/Ethnicity #############
# Read look-up file
race_eth <- read.csv(file= "pop2010race_eth.csv",header=TRUE, sep=",",stringsAsFactors=FALSE)

# Replace race/ethnicity blanks (NAs)  with 0
race_eth$asian_pct <-replace(race_eth$asian_pct, is.na(race_eth$asian_pct), 0)
race_eth$black_pct <-replace(race_eth$black_pct, is.na(race_eth$black_pct), 0)
race_eth$latino_pct <-replace(race_eth$latino_pct, is.na(race_eth$latino_pct), 0)
race_eth$multiple_pct <-replace(race_eth$multiple_pct, is.na(race_eth$multiple_pct), 0)
race_eth$NativeAm_pct <-replace(race_eth$NativeAm_pct, is.na(race_eth$NativeAm_pct), 0)
race_eth$other_pct <-replace(race_eth$other_pct, is.na(race_eth$other_pct), 0)
race_eth$PacificIsl_pct <-replace(race_eth$PacificIsl_pct, is.na(race_eth$PacificIsl_pct), 0)
race_eth$white_pct <-replace(race_eth$white_pct, is.na(race_eth$white_pct), 0)

################## CalEnviroScreen 2.0 ###############################
# set working directory
setwd ("")

# Read CalEnviroScreen Oct2014 Update to region look-up table
ces2 <- read.csv(file= "CES20UpdateOct2014.csv", head=TRUE, sep=",", na.strings=c("NA"))

ces2$ces2_pctile = 100*rank(ces2$CES2Score)/NROW(na.omit(ces2$CES2Score)) 
NROW(na.omit(ces2$CES2Score))

ces2$ces2_pctile <-replace(ces2$ces2_pctile, ces2$ces2_pctile > 100, NA)

# Create top 25% census tracts variable 
ces2$ces2_top25pct <- ifelse(ces2$ces2_pctile > 75,"Yes","No")

# Create quintiles
ces2$quintiles_ces2 <-cut(ces2$ces2_pctile,breaks=c(0,20,40,60,80,101),labels=c("1st","2nd","3rd","4th","5th"),right=FALSE)

# Keep variables of interest, including zip code of census tract
ces2 <- ces2 [,c("CensusTract","ZIP","CES2Score","CES2PercentileRange","ces2_pctile", "quintiles_ces2", "ces2_top25pct")]

# Merge files
dp01 <- merge(dp01,ct2city, by="CensusTract",all.x=TRUE)
dp01 <- merge(dp01,county, by="County_FIPS",all.x=TRUE)
dp01 <- merge(dp01,urb, by ="CensusTract", all.x=TRUE) 
dp01 <- merge(dp01,race_eth, by="CensusTract",all.x=TRUE)
dp01 <- merge(dp01,ces2, by="CensusTract",all.x=TRUE)
hdi  <- merge(dp01, hdi, by="CensusTract",all.x=TRUE)

# Create variable for mapping discrepancies between HDI1.1 and CES2.0

hdi$hdi11_CES2 <- NA
hdi$hdi11_CES2 <- replace(hdi$hdi11_CES2, hdi$hdi_top25pct=="Yes" & hdi$ces2_top25pct=="Yes", "Agree")

hdi$hdi11_CES2 <- replace(hdi$hdi11_CES2, hdi$hdi_top25pct=="Yes" & hdi$ces2_top25pct=="No", "HDI+,CES-")

hdi$hdi11_CES2 <- replace(hdi$hdi11_CES2, hdi$hdi_top25pct=="No" & hdi$ces2_top25pct=="Yes", "HDI-,CES+")

hdi_score<-hdi[,c("CensusTract", "pop2010", "pct2010gq", "City", "ZIP", "County_FIPS", "County_Name", "UrbanType","hdi_total", "hdi_pctile", "quintiles", "quartiles", "hdi_top25pct", "economic", "economic_pctile", "education", "education_pctile", "environment", "environment_pctile", "health", "health_pctile", "neighborhood", "neighborhood_pctile", "social", "social_pctile", "asthma", "asthma_pctile", "costburden", "costburden_pctile", "crowded", "crowded_pctile", "disability", "disability_pctile", "income", "income_pctile", "lbw", "lbw_pctile", "noauto", "noauto_pctile", "noenglish", "noenglish_pctile", "nohighschl", "nohighschl_pctile", "nokitchen", "nokitchen_pctile", "notinhiscl", "notinhiscl_pctile", "notinprscl", "notinprscl_pctile", "novoter10", "novoter10_pctile", "novoter12", "novoter12_pctile", "nowork", "nowork_pctile", "poverty", "poverty_pctile", "poverty_top25pct","parks", "parks_pctile", "pedshurt", "pedshurt_pctile", "pm25", "pm25_pctile", "renters", "renters_pctile", "retail", "retail_pctile", "singlparnt", "singlparnt_pctile", "supermrkt", "supermrkt_pctile", "traffic", "traffic_pctile", "treecanopy", "treecanopy_pctile", "uninsured", "uninsured_pctile", "yll", "yll_pctile", "asian_pct", "black_pct", "latino_pct", "multiple_pct", "NativeAm_pct", "other_pct", "PacificIsl_pct", "white_pct","CES2Score", "CES2PercentileRange", "ces2_pctile", "quintiles_ces2", "ces2_top25pct", "hdi11_CES2","version")] 

# Write out file with name hdiYYYY-MM-DDscore.csv
write.csv(hdi_score, paste0("hdi",format(Sys.time(), "%Y-%m-%d"), "score.csv"), row.names=FALSE)


